# `pyqtorch`

An efficient, large-scale emulator designed for quantum machine learning, seamlessly integrated with a PyTorch backend.

Please refer to https://pyqtorch.readthedocs.io/ for setup and usage info, along with the full documentation.
